@@ -35,18 +35,21 @@ sub get_config_file ()
     "redhat-8.0"      => "redhat-6.2",
     "mandrake-9.0"    => "redhat-6.2",
     "debian-3.0"      => "redhat-6.2",
+    "ubuntu-7.04"     => "redhat-6.2",
     "suse-9.0"        => "redhat-6.2",
     "slackware-9.1.0" => "redhat-6.2",
     "gentoo"          => "redhat-6.2",
     "pld-1.0"         => "pld-1.0",
     "vine-3.0"        => "redhat-6.2",
     "freebsd-5"       => "redhat-6.2",
+    "solaris-2.11"    => "solaris-2.11",
   );
 
   my %dist_table =
   (
-    "redhat-6.2" => "/etc/ntp.conf",
-    "pld-1.0"    => "/etc/ntp/ntp.conf"
+    "redhat-6.2"   => "/etc/ntp.conf",
+    "pld-1.0"      => "/etc/ntp/ntp.conf",
+    "solaris-2.11" => "/etc/inet/ntp.conf",
   );
 
   my $dist = $dist_map{$Utils::Backend::tool{"platform"}};
@@ -138,6 +141,20 @@ sub set_ntp_servers
   return &ntp_conf_replace ($ntp_conf, "server", "[ \t]+", @config);
 }
 
+sub apply_ntp_date
+{
+  my ($config) = @_;
+  my ($servers, $server);
+
+  foreach $server (@$config) {
+      $servers .= " $server";
+  }
+
+  # run ntpdate, this will only be effective
+  # when there isn't any NTP server running
+  &Utils::File::run ("ntpdate -b $servers") if ($servers);
+}
+
 sub get
 {
   return &get_ntp_servers ();
@@ -145,6 +162,7 @@ sub get
 
 sub set
 {
+  &apply_ntp_date (@_);
   return &set_ntp_servers (@_);
 }
 
